@@ -2,12 +2,12 @@ import inspect
 import json
 import logging
 import os
+import sys
 import traceback
 from functools import update_wrapper
 from threading import Lock
 from typing import Dict, List, Union
 
-import sys
 from aws_xray_sdk.core import xray_recorder
 from chalice import AuthResponse, BadRequestError, Rate, Cron
 from chalice import Chalice, Blueprint as ChaliceBlueprint
@@ -30,27 +30,31 @@ class Blueprint(CoworksMixin, ChaliceBlueprint):
 
     """
 
-    def __init__(self, **kwargs):
+    def __init__(self, name=None, **kwargs):
         """Initialize a blueprint.
 
         :param kwargs: Other Chalice parameters.
 
         """
-        import_name = kwargs.pop('import_name', self.__class__.__name__)
+        import_name = name or self.__class__.__name__.lower()
         super().__init__(import_name)
 
     @property
-    def import_name(self):
+    def name(self):
         return self._import_name
 
-    @property
-    def component_name(self):
-        return ''
-
     @property
     def current_app(self):
         return self._current_app
 
+    def deferred_init(self, workspace):
+        for func in self.before_first_activation_funcs:
+            self.current_app.before_first_activation(func)
+        for func in self.before_activation_funcs:
+            self.current_app.before_activation(func)
+        for func in self.after_activation_funcs:
+            self.current_app.after_activation(func)
+
 
 class TechMicroService(CoworksMixin, Chalice):
     """Simple tech microservice created directly from class.
@@ -59,42 +63,31 @@ class TechMicroService(CoworksMixin, Chalice):
     
     """
 
-    def __init__(self, ms_name: str = None, configs: Union[Config, List[Config]] = None, **kwargs):
+    def __init__(self, name: str = None, configs: Union[Config, List[Config]] = None, **kwargs):
         """ Initialize a technical microservice.
-        :param ms_name: Name used to identify the resource.
+        :param name: Name used to identify the microservice.
         :param configs: Deployment configuration.
         :param workspace used for execution.
         :param kwargs: Other Chalice parameters.
         """
-        ms_name = ms_name or self.__class__.__name__
+        name = name or self.__class__.__name__.lower()
 
         self.configs = configs or [Config()]
         if type(self.configs) is not list:
             self.configs = [configs]
         self.config = None
 
-        super().__init__(app_name=ms_name, **kwargs)
+        super().__init__(app_name=name, **kwargs)
+
+        # Blueprints and extended commands added
         self.experimental_feature_flags.update([
             'BLUEPRINTS'
         ])
-
-        # App and blueprints init deferered functions.
-        self.deferred_inits = []
-        self.blueprint_deferred_inits = []
-
-        # Extended commands added
+        self.blueprints = {}
         self.commands = {}
 
-        # A list of functions that will be called at the first activation.
-        # To register a function, use the :meth:`before_first_request` decorator.
-        self.before_first_activation_funcs = []
-
-        # A list of functions that will be called at the beginning of each activation.
-        # To register a function, use the :meth:`before_activation` decorator.
-        self.before_activation_funcs = []
-
-        self.after_activation_funcs = []
-
+        # App init deferered functions.
+        self.deferred_inits = []
         self._got_first_activation = False
         self._before_activation_lock = Lock()
 
@@ -107,11 +100,7 @@ class TechMicroService(CoworksMixin, Chalice):
         self.__global_auth__ = None
 
     @property
-    def component_name(self):
-        return class_attribute(self, 'url_prefix', '')
-
-    @property
-    def ms_name(self):
+    def name(self):
         return self.app_name
 
     @property
@@ -120,49 +109,62 @@ class TechMicroService(CoworksMixin, Chalice):
 
     def deferred_init(self, workspace):
         if self.entries is None:
-            self._init_routes(workspace=workspace)
+            url_prefix = class_attribute(self, 'url_prefix', '')
+            self._init_routes(workspace=workspace, url_prefix=url_prefix)
             for deferred_init in self.deferred_inits:
                 deferred_init(workspace)
-            for deferred_init in self.blueprint_deferred_inits:
-                deferred_init(workspace)
+            for blueprint in self.iter_blueprints():
+                blueprint.deferred_init(workspace)
 
-    def register_blueprint(self, blueprint: Blueprint, authorizer=None, **kwargs):
+    def register_blueprint(self, blueprint: Blueprint, authorizer=None, url_prefix=None, hide_routes=False,
+                           **kwargs):
         """ Register a :class:`Blueprint` on the microservice.
 
         :param blueprint:
         :param authorizer:
+        :param url_prefix:
+        :param hide_routes:
         :param kwargs:
         :return:
         """
         if 'name_prefix' not in kwargs:
-            kwargs['name_prefix'] = blueprint.component_name
+            kwargs['name_prefix'] = blueprint.name
         if 'url_prefix' not in kwargs:
-            kwargs['url_prefix'] = f"/{blueprint.component_name}"
+            kwargs['url_prefix'] = f"/{blueprint.name}"
 
-        blueprint.__auth__ = self._create_auth_proxy(self, authorizer) if authorizer else None
+        if url_prefix in self.blueprints:
+            raise NameError(f"A blueprint is already defined for the {url_prefix} prefix.")
+        self.blueprints[url_prefix] = blueprint
+
+        if not hide_routes:
+            blueprint.__auth__ = self._create_auth_proxy(self, authorizer) if authorizer else None
 
         def deferred(workspace):
-            self._init_routes(workspace=workspace, component=blueprint, url_prefix=kwargs['url_prefix'])
-            Chalice.register_blueprint(self, blueprint, **kwargs)
+            if not hide_routes:
+                self._init_routes(workspace=workspace, component=blueprint, url_prefix=url_prefix)
+            Chalice.register_blueprint(self, blueprint, url_prefix=url_prefix)
 
-        self.blueprint_deferred_inits.append(deferred)
+        self.deferred_inits.append(deferred)
 
-    def execute(self, command, *, project_dir, module, workspace, output=None, error=None, **kwargs):
-        """Executes a client command."""
+    def iter_blueprints(self):
+        return self.blueprints.values()
+
+    def execute(self, command, *, project_dir, module, service=None, workspace, output=None, error=None, **kwargs):
+        """Executes a coworks command."""
         from coworks.cws.client import ProjectConfig
-        from coworks.cws.command import CwsCommandOptions
 
         project_config = ProjectConfig(command, project_dir)
-        service = kwargs.setdefault('service', self.ms_name)
+        if not service:
+            service = self.name
         cmd = project_config.get_command(self, module, service, workspace)
         if not cmd:
-            raise CwsCommandError(f"The command {command} was not added to the microservice {self.ms_name}.\n")
+            raise CwsCommandError(f"The command {command} was not added to the microservice {self.name}.\n")
 
-        options = CwsCommandOptions(cmd, project_dir=project_dir, module=module, workspace=workspace, **kwargs)
-        project_config.complete_options(options)
-        cmd.execute(options=options, output=output, error=error)
+        client_params = {'project_dir': project_dir, 'module': module, 'service': service, 'workspace': workspace}
+        complemented_args = project_config.missing_options(**client_params, **kwargs)
+        cmd.execute(output=output, error=error, **client_params, **complemented_args)
 
-    def _init_routes(self, *, workspace=DEFAULT_WORKSPACE, component=None, url_prefix=None):
+    def _init_routes(self, *, workspace=DEFAULT_WORKSPACE, component=None, url_prefix=''):
         if self.config is None:
             for conf in self.configs:
                 if conf.workspace == workspace:
@@ -196,12 +198,12 @@ class TechMicroService(CoworksMixin, Chalice):
 
             # Get function's route
             if func.__name__ == method:
-                route = f"{component.component_name}"
+                route = f"{url_prefix}"
             else:
                 name = func.__name__[len(method) + 1:]
                 name = trim_underscores(name)  # to allow several functions with same route but different args
                 name = name.replace('_', '/')
-                route = f"{component.component_name}/{name}" if component.component_name else f"{name}"
+                route = f"{url_prefix}/{name}" if url_prefix else f"{name}"
 
             # Get parameters
             args = inspect.getfullargspec(func).args[1:]
@@ -220,12 +222,14 @@ class TechMicroService(CoworksMixin, Chalice):
             proxy = component._create_rest_proxy(func, kwarg_keys, args, varkw)
 
             # complete all entries
-            component.route(f"/{route}", methods=[method.upper()], authorizer=auth, cors=self.config.cors,
-                            content_types=['multipart/form-data', 'application/json', 'text/plain'])(proxy)
+            if not route.startswith('/'):
+                route = '/' + route
+            self.route(f"{route}", methods=[method.upper()], authorizer=auth, cors=self.config.cors,
+                       content_types=list(self.config.content_type))(proxy)
             if url_prefix:
-                self.entries[f"{url_prefix}/{route}"] = (method.upper(), func)
+                self.entries[f"{url_prefix}{route}"] = (method.upper(), func)
             else:
-                self.entries[f"/{route}"] = (method.upper(), func)
+                self.entries[f"{route}"] = (method.upper(), func)
 
     @staticmethod
     def _create_auth_proxy(component, auth_method):
@@ -258,44 +262,31 @@ class TechMicroService(CoworksMixin, Chalice):
         return component.authorizer(name='auth')(proxy)
 
     def __call__(self, event, context):
-        # workspace = self._called_workspace(event, context)
-
-        with self._before_activation_lock:
-            workspace = os.environ['WORKSPACE']
-            self.deferred_init(workspace=workspace)
-
-            if not self._got_first_activation:
-                for func in self.before_first_activation_funcs:
-                    func()
-                self._got_first_activation = True
-
-        for func in self.before_activation_funcs:
-            func()
-
+        """Lambda handler."""
+        self.do_before_first_activation()
+        self.do_before_activation()
         res = self.handler(event, context)
-
-        for func in self.after_activation_funcs:
-            func()
-
+        self.do_after_activation()
         return res
 
     def handler(self, event, context):
+        """Main microservice entry point."""
 
         # authorization call
         if event.get('type') == 'TOKEN':
             if self.debug:
-                print(f"Calling {self.ms_name} for authorization")
+                print(f"Calling {self.name} for authorization")
 
             if self.__auth__:
                 return self.__auth__(event, context)
 
-            print(f"Undefined authorization method for {self.ms_name} ")
+            print(f"Undefined authorization method for {self.name} ")
             return 'Unauthorized', 403
 
         # step function call
         if event.get('type') == 'CWS_SFN':
             if self.debug:
-                print(f"Calling {self.ms_name} by step function")
+                print(f"Calling {self.name} by step function")
 
             self.sfn_call = True
             content_type = event['headers']['Content-Type']
@@ -311,7 +302,7 @@ class TechMicroService(CoworksMixin, Chalice):
                 raise BadRequestError(f"Undefined content type {content_type} for Step Function call")
         else:
             if self.debug:
-                print(f"Calling {self.ms_name} with event {event}")
+                print(f"Calling {self.name} with event {event}")
 
         res = super().__call__(event, context)
 
@@ -324,7 +315,7 @@ class TechMicroService(CoworksMixin, Chalice):
                 pass
 
         if self.debug:
-            print(f"Call {self.ms_name} returns {res}")
+            print(f"Call {self.name} returns {res}")
 
         return res
 
@@ -339,40 +330,30 @@ class TechMicroService(CoworksMixin, Chalice):
         self.deferred_inits.append(f)
         return f
 
-    def before_first_activation(self, f):
-        """Registers a function to be run before the first activation of the microservice.
+    def do_before_first_activation(self):
+        """Calls all before first activation functions."""
+        if self._got_first_activation:
+            return
 
-        May be used as a decorator.
+        # lock needed only if boolean may change value
+        with self._before_activation_lock:
+            workspace = os.environ['WORKSPACE']
+            self.deferred_init(workspace=workspace)
 
-        The function will be called without any arguments and its return value is ignored.
-        """
+            if not self._got_first_activation:
+                for func in self.before_first_activation_funcs:
+                    func()
+                self._got_first_activation = True
 
-        self.before_first_activation_funcs.append(f)
-        return f
+    def do_before_activation(self):
+        """Calls all before activation functions."""
+        for func in self.before_activation_funcs:
+            func()
 
-    def before_activation(self, f):
-        """Registers a function to run before each activation of the microservice.
-        :param f:  Function added to the list.
-        :return: None.
-
-        May be used as a decorator.
-
-        The function will be called without any arguments and its return value is ignored.
-        """
-
-        self.before_activation_funcs.append(f)
-        return f
-
-    def after_activation(self, f):
-        """Registers a function to be run after each activation of the microservice.
-
-        May be used as a decorator.
-
-        The function will be called without any arguments and its return value is ignored.
-        """
-
-        self.after_activation_funcs.append(f)
-        return f
+    def do_after_activation(self):
+        """Calls all after activation functions."""
+        for func in self.after_activation_funcs:
+            func()
 
 
 class BizFactory(TechMicroService):
@@ -380,7 +361,7 @@ class BizFactory(TechMicroService):
     """
 
     def __init__(self, sfn_name, **kwargs):
-        super().__init__(ms_name=sfn_name, **kwargs)
+        super().__init__(name=sfn_name, **kwargs)
 
         self.aws_profile = self.__sfn_client__ = self.__sfn_arn__ = None
         self.sfn_name = sfn_name
@@ -390,18 +371,6 @@ class BizFactory(TechMicroService):
         def check_sfn():
             return self.sfn_arn
 
-    @property
-    def ms_type(self):
-        return 'biz'
-
-    @property
-    def trigger_sources(self):
-
-        def to_dict(name, trigger):
-            return {'name': f"{self.sfn_name}-{name}", **trigger.to_dict()}
-
-        return [to_dict(name, biz.trigger) for name, biz in self.biz.items()]
-
     @property
     def sfn_client(self):
         if self.__sfn_client__ is None:
@@ -416,7 +385,7 @@ class BizFactory(TechMicroService):
             res = self.sfn_client.list_state_machines()
             while True:
                 for sfn in res['stateMachines']:
-                    if sfn['name'] == self.sfn_name:
+                    if sfn['name'] == os.environ['SFN_NAME']:
                         self.__sfn_arn__ = sfn['stateMachineArn']
                         return self.__sfn_arn__
 
@@ -427,78 +396,87 @@ class BizFactory(TechMicroService):
                 res = self.sfn_client.list_state_machines(nextToken=next_token)
         return self.__sfn_arn__
 
-    def get_sfn_name(self):
-        """Returns the name of the associated step function."""
-        return self.sfn_name
+    @property
+    def trigger_sources(self):
 
-    def get_sfn_arn(self):
-        """Returns the arn of the associated step function."""
-        return self.sfn_arn
+        def to_dict(name, trigger):
+            return {'name': f"{self.sfn_name}-{name}", **trigger.to_dict()}
 
-    def get_biz_names(self):
-        """Returns the list of biz microservices defined in the factory."""
-        return [name for name in self.biz]
+        return [to_dict(name, biz.trigger) for name, biz in self.biz.items()]
 
-    def post_trigger(self, biz_name, data=None):
-        """Manual triggering a biz microservice."""
-        if self.debug:
-            print(f"Manual triggering: {biz_name}")
-
-        data = data or {}
-        try:
-            self.biz[biz_name].data.update(data)
-            return self.biz[biz_name](data, {})
-        except KeyError:
-            if self.debug:
-                print(f"Cannot found {biz_name} in services {[k for k in self.biz.keys()]}")
-            raise BadRequestError(f"Cannot found {biz_name} biz microservice")
-
-    def create(self, biz_name, trigger=None, data: dict = None, **kwargs):
+    def create(self, biz_name, trigger=None, configs: List[Config] = None, **kwargs):
         """Creates a biz microservice. If the trigger is not defined the microservice can only be triggered manually."""
 
         if biz_name in self.biz:
             raise BadRequestError(f"Biz microservice {biz_name} already defined for {self.sfn_name}")
 
-        self.biz[biz_name] = BizMicroService(self, data, trigger, ms_name=biz_name, **kwargs)
+        self.biz[biz_name] = BizMicroService(self, trigger, configs, name=biz_name, **kwargs)
         return self.biz[biz_name]
 
     def invoke(self, data):
         res = self.sfn_client.start_execution(stateMachineArn=self.sfn_arn, input=json.dumps(data if data else {}))
         return json.dumps(res, indent=4, sort_keys=True, default=str)
 
-    def handler(self, event, context):
-        if 'detail-type' in event and event['detail-type'] == 'Scheduled Event':
-            res_name = event['resources'][0].split('/')[-1]
-            if not res_name.startswith(self.sfn_name):
-                raise BadRequestError(f"Biz {self.sfn_name} called with resource {res_name}")
-
-            biz_name = res_name[len(self.sfn_name) + 1:]
-            if biz_name not in self.biz:
-                raise BadRequestError(f"Unregistered biz : {biz_name}")
-
-            if self.debug:
-                print(f"Trigger: {biz_name}")
-
-            return self.biz[biz_name](event, context)
-
-        return super().handler(event, context)
-
 
 class BizMicroService(TechMicroService):
     """Biz composed microservice activated by a reactor.
     """
 
-    def __init__(self, biz_factory, data, trigger, **kwargs):
+    def __init__(self, biz_factory, trigger, configs, **kwargs):
         super().__init__(**kwargs)
         self.biz_factory = biz_factory
-        self.data = data
+        self.configs = configs
         self.trigger = trigger
 
+    @property
+    def ms_type(self):
+        return 'biz'
+
+    @property
+    def trigger_source(self):
+        return self.trigger.to_dict()
+
+    def get_sfn_name(self):
+        """Returns the name of the associated step function."""
+        return self.biz_factory.sfn_name
+
+    def get_sfn_arn(self):
+        """Returns the arn of the associated step function."""
+        return self.biz_factory.sfn_arn
+
+    def get_biz_names(self):
+        """Returns the list of biz microservices defined in the factory."""
+        return [name for name in self.biz_factory]
+
+    def get_default_data(self):
+        try:
+            workspace = os.environ['WORKSPACE']
+        except KeyError:
+            raise EnvironmentError("environment variable WORKSPACE is not defined")
+        try:
+            default_data = next(c.data for c in self.configs if c.workspace == workspace)
+        except StopIteration:
+            print(f"No configuration found for workspace {workspace} in {self.configs}")
+            default_data = {}
+        except KeyError:
+            default_data = {}
+        return default_data
+
+    def post_trigger(self, data=None):
+        data = data or {}
+        data.update(self.get_default_data())
+        return self.biz_factory.invoke(data)
+
     def handler(self, event, context):
-        return self.biz_factory.invoke(self.data)
+        if 'detail-type' in event and event['detail-type'] == 'Scheduled Event':
+            if self.debug:
+                print(f"Trigger: {self.biz_factory.sfn_name}")
+            return self.biz_factory.invoke(self.get_default_data())
+
+        return super().handler(event, context)
 
 
-def hide_entry(f):
+def hide(f):
     """Hide a route of the microservice.
 
      May be used as a decorator.
