@@ -3,18 +3,17 @@ from functools import partial
 
 import anyconfig
 import click
-from chalice.cli import chalice_version, get_system_info
 
 from coworks.config import DEFAULT_PROJECT_DIR, DEFAULT_WORKSPACE
-from coworks.cws.command import CwsCommandOptions
 from coworks.cws.error import CwsClientError
 from coworks.utils import import_attr
 from coworks.version import __version__
 
+from .utils import get_system_info
+
 
 @click.group()
-@click.version_option(version=__version__,
-                      message=f'%(prog)s %(version)s, chalice {chalice_version}, {get_system_info()}')
+@click.version_option(version=__version__, message=f'%(prog)s %(version)s, {get_system_info()}')
 @click.option('-p', '--project-dir', default=DEFAULT_PROJECT_DIR,
               help='The project directory path (absolute or relative). Defaults to CWD')
 @click.option('-m', '--module', help="Filename of your microservice python source file.")
@@ -28,10 +27,11 @@ def client(*args, **kwargs):
 def invoke(initial, ctx):
     """Invokes the command over the service or the declared services in project configuration file."""
     try:
-        cmd_name = ctx.protected_args[0] if ctx.protected_args else None
         args = ctx.args
         protected_args = ctx.protected_args
 
+        cmd_name = protected_args[0] if protected_args else None
+
         project_dir = ctx.params.get('project_dir')
         module = ctx.params.get('module')
         service = ctx.params.get('service')
@@ -45,7 +45,7 @@ def invoke(initial, ctx):
 
         # Iterates over the declared services in project configuration file
         for module, service in services:
-            ctx.args = args
+            ctx.args = list(args)
             ctx.protected_args = protected_args
 
             # Get command from the microservice
@@ -55,22 +55,15 @@ def invoke(initial, ctx):
             if not cmd:
                 raise CwsClientError(f"Undefined command {cmd_name}.\n")
 
-            # Defines the proxy command with all user options
-            def call_execute(**command_options):
-                try:
-                    options = CwsCommandOptions(cmd, project_dir=project_dir, module=module, service=service,
-                                                workspace=workspace, **command_options)
-                    cmd_project_config.complete_options(options)
-                    cmd.execute(options=options)
-                except Exception as err:
-                    raise CwsClientError(str(err))
+            # Get user defined options and convert them in right types
+            client_opts, _, cmd_opts = cmd.make_parser(ctx).parse_args(ctx.args)
+            for opt_key, opt_value in client_opts.items():
+                cmd_opt = next(x for x in cmd_opts if x.name == opt_key)
+                client_opts[opt_key] = cmd_opt.type(opt_value)
 
-            for opt in cmd.options:
-                call_execute = opt(call_execute)
-            client.command(cmd_name)(call_execute)
-
-            # Call the command from click
-            initial(ctx)
+            client_params = {'project_dir': project_dir, 'module': module, 'service': service, 'workspace': workspace}
+            complemented_args = cmd_project_config.missing_options(**client_params, **client_opts)
+            cmd.execute(**client_params, **complemented_args)
     except CwsClientError as client_err:
         sys.stderr.write(client_err.msg)
         sys.exit(1)
@@ -130,13 +123,16 @@ class ProjectConfig:
                 proj = ProjectConfig(needed, self.project_dir)
                 proj.get_command(ms, module, service, workspace)
 
+            click.help_option()(cmd)
             return cmd
 
-    def complete_options(self, options):
+    def missing_options(self, project_dir, module, service, workspace, **options):
         """Adds project options to the command options."""
-        for key in self._all_options_keys(options.module, options.service, options.workspace):
+        for key in self._all_options_keys(module, service, workspace):
+            if key == 'class':
+                continue
             if key not in options or options[key] is None:
-                options[key] = self._get_option(options.module, options.service, options.workspace, key)
+                options[key] = self._get_option(module, service, workspace, key)
         return options
 
     @property
