@@ -13,6 +13,7 @@ from chalice.config import Config
 from chalice.local import ChaliceRequestHandler, LocalGateway, LocalDevServer
 
 from .command import CwsCommand
+from .utils import threaded
 
 
 class CwsRunner(CwsCommand):
@@ -28,7 +29,8 @@ class CwsRunner(CwsCommand):
             click.option('--debug/--no-debug', default=False, help='Print debug logs to stderr.')
         ]
 
-    def _execute(self, options):
+    @threaded
+    def _execute(self, *, project_dir, workspace, host, port, debug, **options):
         """ Runs the microservice in a local Chalice emulator.
 
         :param host: the hostname to listen on.
@@ -43,18 +45,17 @@ class CwsRunner(CwsCommand):
         from .factory import CwsFactory
 
         ms = self.app
-        os.environ['WORKSPACE'] = options.workspace
-        ms.config.load_environment_variables(options.project_dir)
+        os.environ['WORKSPACE'] = workspace
+        ms.config.load_environment_variables(project_dir)
         if ms.entries is None:
-            ms.deferred_init(options.workspace)
+            ms.deferred_init(workspace)
 
-        if options['debug']:
+        if debug:
             logging.basicConfig(stream=sys.stdout, level=logging.INFO, format='%(message)s')
 
-        factory = CwsFactory(ms, options.project_dir, debug=options['debug'])
+        factory = CwsFactory(ms, project_dir, debug=debug)
         config = factory.mock_config_obj(ms)
-        ms.local_server = LocalDevServer(ms, config, options['host'], options['port'],
-                                         handler_cls=CwsRequestHandler)
+        ms.local_server = LocalDevServer(ms, config, host, port, handler_cls=CwsRequestHandler)
         ms.__class__ = type('LocalMicroService', (ms.__class__, ThreadedMixin), {})
         ms.local_server.serve_forever()
 
@@ -93,7 +94,6 @@ class ThreadedMixin:
         self._THREAD_LOCAL.current_request = value
 
 
-
 class ThreadedLocalServer(Thread):
     threaded_servers = {}
 
