@@ -24,29 +24,29 @@ class SqlMicroService(TechMicroService):
         @self.before_first_activation
         def check_env_vars():
             if self.dialect is None:
-                self.dialect = os.getenv('DIALECT')
+                self.dialect = os.getenv(self.dialect_env_var_name)
                 if not self.dialect:
-                    raise EnvironmentError('DIALECT not defined in environment')
+                    raise EnvironmentError(f"{self.dialect_env_var_name} not defined in environment.")
             if self.host is None:
-                self.host = os.getenv('HOST')
+                self.host = os.getenv(self.host_env_var_name)
                 if not self.host:
-                    raise EnvironmentError('HOST not defined in environment')
+                    raise EnvironmentError(f"{self.host_env_var_name} not defined in environment.")
             if self.port is None:
-                self.port = os.getenv('PORT')
+                self.port = os.getenv(self.port_env_var_name)
                 if self.port is None:
-                    if self.dialect == 'mysql':
+                    if self.dialect.startswith('mysql'):
                         self.port = 3306
                     elif self.dialect == 'postgres':
                         self.port = 5432
             if self.dbname is None:
-                self.dbname = os.getenv('DB_NAME')
+                self.dbname = os.getenv(self.dbname_env_var_name)
                 if not self.dbname:
-                    raise EnvironmentError('DB_NAME not defined in environment')
+                    raise EnvironmentError(f"{self.dbname_env_var_name} not defined in environment.")
             if self.user is None:
-                self.user = os.getenv('USER')
+                self.user = os.getenv(self.user_env_var_name)
                 if not self.user:
-                    raise EnvironmentError('USER not defined in environment')
-            self.password = os.getenv('PASSWD', '')
+                    raise EnvironmentError(f"{self.user_env_var_name} not defined in environment.")
+            self.password = os.getenv(self.passwd_env_var_name, '')
 
         @self.before_activation
         def set_session():
@@ -73,3 +73,27 @@ class SqlMicroService(TechMicroService):
         metadata = MetaData(bind=self.engine)
         return list(
             map(lambda table: Table(table, metadata, autoload=True, autoload_with=self.engine, schema=schema), tables))
+
+    @property
+    def dialect_env_var_name(self):
+        return 'DIALECT'
+
+    @property
+    def host_env_var_name(self):
+        return 'HOST'
+
+    @property
+    def port_env_var_name(self):
+        return 'PORT'
+
+    @property
+    def dbname_env_var_name(self):
+        return 'DBNAME'
+
+    @property
+    def user_env_var_name(self):
+        return 'USER'
+
+    @property
+    def passwd_env_var_name(self):
+        return 'PASSWD'
