@@ -1,4 +1,5 @@
 from coworks import TechMicroService
+from coworks.cws.runner import CwsRunner
 
 
 class SimpleMicroService(TechMicroService):
@@ -8,3 +9,4 @@ class SimpleMicroService(TechMicroService):
 
 
 app = SimpleMicroService()
+CwsRunner(app)
