@@ -8,12 +8,12 @@ from coworks import TechMicroService
 
 class TechMS(TechMicroService):
     def __init__(self, **kwargs):
-        super().__init__(ms_name='test', **kwargs)
+        super().__init__(name='test', **kwargs)
 
 
 class S3MockTechMS(TechMicroService):
     def __init__(self):
-        super().__init__(ms_name='test')
+        super().__init__(name='test')
         session = MagicMock()
         session.client = MagicMock()
         s3_object = {'Body': io.BytesIO(b'test'), 'ContentType': 'text/plain'}
@@ -106,8 +106,14 @@ class TupleReturnedMS(TechMS):
     def get(self):
         return 'ok', 200
 
+    def get_json(self):
+        return {'value': 'ok'}, 200
+
     def get_resp(self, str):
         return Response(body=str, status_code=200)
 
     def get_error(self, str):
         return str, 300
+
+    def get_tuple(self, str):
+        return (str, 200, {'x-test': 'true'})
