@@ -7,45 +7,61 @@ class TestClass:
 
     def test_info_wront_project_dir(self, example_dir, capsys):
         with pytest.raises(SystemExit) as pytest_wrapped_e:
-            client(prog_name='cws', args=['-p', 'doesntexist', 'info'], obj={})
+            client(prog_name='cws', args=['-p', 'doesntexist', 'test'], obj={})
         assert pytest_wrapped_e.type == SystemExit
         assert pytest_wrapped_e.value.code == 1
 
     def test_info_no_service(self, example_dir, capsys):
         with pytest.raises(SystemExit) as pytest_wrapped_e:
-            client(prog_name='cws', args=['-p', example_dir, '-m', 'quickstart2', 'info'], obj={})
+            client(prog_name='cws', args=['-p', example_dir, '-m', 'quickstart2', 'cmd'], obj={})
         assert pytest_wrapped_e.type == SystemExit
         assert pytest_wrapped_e.value.code == 1
 
     def test_info_wrong_service(self, example_dir, capsys):
         with pytest.raises(SystemExit) as pytest_wrapped_e:
-            client(prog_name='cws', args=['-p', example_dir, '-m', 'example', '-s', 'test', 'info'], obj={})
+            client(prog_name='cws', args=['-p', example_dir, '-m', 'example', '-s', 'test', 'test'], obj={})
         assert pytest_wrapped_e.type == SystemExit
         assert pytest_wrapped_e.value.code == 1
 
     def test_info(self, example_dir, capsys):
         with pytest.raises(SystemExit) as pytest_wrapped_e:
-            client(prog_name='cws', args=['-p', example_dir, '-m', 'example', '-s', 'tech_app', 'info'], obj={})
+            client(prog_name='cws', args=['-p', example_dir, '-m', 'example', '-s', 'tech_app', 'test'], obj={})
         assert pytest_wrapped_e.type == SystemExit
         assert pytest_wrapped_e.value.code == 0
         captured = capsys.readouterr()
-        assert captured.out == "info passed on TechMS"
+        assert captured.out == "test command with a=default/test command with b=value"
 
     def test_info_wrong_option(self, example_dir, capsys):
         with pytest.raises(SystemExit) as pytest_wrapped_e:
-            client(prog_name='cws', args=['-p', example_dir, '-m', 'example', '-s', 'tech_app', 'info', '-t', 'wrong'],
+            client(prog_name='cws', args=['-p', example_dir, '-m', 'example', '-s', 'tech_app', 'test', '-t', 'wrong'],
                    obj={})
         assert pytest_wrapped_e.type == SystemExit
         assert pytest_wrapped_e.value.code == 1
 
     def test_info_right_option(self, example_dir, capsys):
         with pytest.raises(SystemExit) as pytest_wrapped_e:
-            client(prog_name='cws', args=['-p', example_dir, '-m', 'example', '-s', 'tech_app', 'info', '-h', 'right'],
+            client(prog_name='cws', args=['-p', example_dir, '-m', 'example', '-s', 'tech_app', 'test', '-a', 'right'],
                    obj={})
         assert pytest_wrapped_e.type == SystemExit
         assert pytest_wrapped_e.value.code == 0
         captured = capsys.readouterr()
-        assert captured.out == "info passed on right"
+        assert captured.out == "test command with a=right/test command with b=value"
+
+    def test_info_wrong_b_option(self, example_dir, capsys):
+        with pytest.raises(SystemExit) as pytest_wrapped_e:
+            client(prog_name='cws', args=['-p', example_dir, '-m', 'example', '-s', 'tech_app', 'test', '-b', 'right'],
+                   obj={})
+        assert pytest_wrapped_e.type == SystemExit
+        assert pytest_wrapped_e.value.code == 1
+
+    def test_info_right_b_option(self, example_dir, capsys):
+        with pytest.raises(SystemExit) as pytest_wrapped_e:
+            client(prog_name='cws', args=['-p', example_dir, '-m', 'example', '-s', 'tech_app', 'test', '--b', 'right'],
+                   obj={})
+        assert pytest_wrapped_e.type == SystemExit
+        assert pytest_wrapped_e.value.code == 0
+        captured = capsys.readouterr()
+        assert captured.out == "test command with a=default/test command with b=right"
 
     def test_run(self, example_dir):
         with pytest.raises(SystemExit) as pytest_wrapped_e:
@@ -53,6 +69,13 @@ class TestClass:
         assert pytest_wrapped_e.type == SystemExit
         assert pytest_wrapped_e.value.code == 1
 
+    def test_run_with_int_option(self, example_dir):
+        with pytest.raises(SystemExit) as pytest_wrapped_e:
+            client(prog_name='cws', args=['-p', example_dir, '-m', 'example', '-s', 'project1', 'run', '-p', '8000'],
+                   obj={})
+        assert pytest_wrapped_e.type == SystemExit
+        assert pytest_wrapped_e.value.code == 0
+
     def test_export(self, example_dir):
         with pytest.raises(SystemExit) as pytest_wrapped_e:
             client(prog_name='cws',
