@@ -1,13 +1,13 @@
 import io
 import json
+import os
 from unittest.mock import Mock, MagicMock
 
 import pytest
 import yaml
 
 from coworks import BizFactory
-from coworks.cws.command import CwsCommandOptions
-from coworks.cws.sfn import StepFunctionWriter, StepFunction, TechState
+from coworks.cws.sfn import StepFunction, TechState, CwsSFNTranslater
 from coworks.cws.writer import CwsWriterError
 from tests.src.coworks.tech_ms import S3MockTechMS
 
@@ -22,7 +22,8 @@ class TestStepFunction(StepFunction):
         with filepath.open() as file:
             self.data = yaml.load(file, Loader=yaml.SafeLoader)
 
-        super().__init__("test", filepath)
+        options = {'module': None, 'service': None, 'project_dir': None, 'workspace': None}
+        super().__init__("test", filepath, account_number='123412341234', **options)
 
 
 class TechMS(S3MockTechMS):
@@ -41,6 +42,7 @@ class TechMS(S3MockTechMS):
 
 
 class TestClass:
+    os.environ["WORKSPACE"] = ''  # not sure where this should be set
 
     def test_no_params(self):
         tech = TechMS()
@@ -93,21 +95,20 @@ class TestClass:
     def test_biz_empty(self):
         biz = BizFactory('tests/src/coworks/biz/empty')
         biz.create('test')
-        writer = StepFunctionWriter(biz)
-        self.io = io.StringIO()
-        output = self.io
+        translater = CwsSFNTranslater(biz)
+        output = io.StringIO()
         with pytest.raises(CwsWriterError):
-            options = CwsCommandOptions(writer, project_dir='.', module='', service='', workspace='dev')
-            writer.execute(options=options, output=output, error=output)
+            options = {'project_dir': '.', 'module': '', 'service': '', 'workspace': 'dev'}
+            translater.execute(output=output, error=output, **options)
 
     def test_biz_complete(self):
         """Tests the doc example."""
         fact = BizFactory('tests/src/coworks/biz/complete')
         fact.create('test')
-        writer = StepFunctionWriter(fact)
+        translater = CwsSFNTranslater(fact)
         output = io.StringIO()
-        options = CwsCommandOptions(writer, project_dir='.', module='', service='', workspace='dev')
-        writer.execute(options=options, output=output, error=output)
+        options = {'project_dir': '.', 'module': '', 'service': '', 'workspace': 'dev'}
+        translater.execute(output=output, error=output, **options)
         output.seek(0)
         source = json.loads(output.read())
         assert source['Version'] == "1.0"
